==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/viewer/l10n/ast.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Un xestor de ficheros cenciellu con presentación de diapositives pa elementos multimedia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Comparti les últimes semeyes y vídeos de les vacaciones como nos filmes, amuesa un migayín de la to última novela dende Nextcloud, escueyi'l meyor GIF de la to coleición gracies a la previsualización direuta de los ficheros favoritos y fai munches más coses.",
    "Your browser does not support audio." : "El restolador nun ye compatible col audiu.",
    "Error loading {name}" : "Hebo un error al cargar «{name}»",
    "Image saved" : "Guardóse la imaxe",
    "Error saving image" : "Hebo un error al guardar la imaxe",
    "Unsaved changes" : "Cambeos ensin guardar",
    "Drop changes" : "Escartar los cambeos",
    "Your browser does not support videos." : "El restolador nun ye compatible colos vídeos.",
    "Edit" : "Editar",
    "Exit full screen" : "Colar de la pantalla completa",
    "Full screen" : "Pantalla completa",
    "Open sidebar" : "Abrir la barra llateral",
    "Download" : "Baxar",
    "Delete" : "Desaniciar",
    "This file no longer exists" : "Esti ficheru yá nun esiste",
    "There is no plugin available to display this file type" : "Nun hai nengún plugin disponible p'amosar esti tipu de ficheru",
    "View" : "Ver",
    "Name" : "Nome",
    "Save" : "Guardar",
    "Save as" : "Guardar como",
    "Back" : "Atrás",
    "Loading …" : "Cargando…",
    "Reset" : "Reafitar",
    "All changes will be lost." : "Van perdese tolos cambeos.",
    "Are you sure you want to continue?" : "¿De xuru que quies siguir?",
    "Cancel" : "Encaboxar",
    "Continue" : "Siguir",
    "Undo" : "Desfacer",
    "Redo" : "Refacer",
    "Show original image" : "Amosar la imaxe orixinal",
    "Zoom in" : "Averar",
    "Zoom out" : "Alloñar",
    "Toggle zoom menu" : "Alternar el menú del zoom",
    "Adjust" : "Axustar",
    "Fine-tune" : "Axuste finu",
    "Filters" : "Filtros",
    "Watermark" : "Marca d'agua",
    "Draw" : "Dibuxar",
    "Resize" : "Redimensionar",
    "Invalid image." : "La imaxe ye inválida.",
    "Error while uploading the image." : "Hebo un error mentanto se xubía la imaxe.",
    "are not images" : "nun son imáxenes",
    "is not an image" : "nun ye una imaxe",
    "to be uploaded" : "a xubir",
    "Crop" : "Recortar",
    "Original" : "Orixinal",
    "Custom" : "Personalizar",
    "Square" : "Cuadráu",
    "Landscape" : "Horizontal",
    "Portrait" : "Vertical",
    "Ellipse" : "Elipse",
    "Classic TV" : "TV clásica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flecha",
    "Blur" : "Emborrinar",
    "Brightness" : "Brillu",
    "Contrast" : "Contraste",
    "Flip X" : "Voltiar la exa X",
    "Flip Y" : "Voltiar la exa Y",
    "Hue" : "Tonu",
    "Saturation" : "Saturación",
    "Value" : "Valor",
    "Image" : "Imaxe",
    "Importing …" : "Importando…",
    "+ Add image" : "+ Amestar una imaxe",
    "Line" : "Llinia",
    "Pen" : "Pluma",
    "Polygon" : "Polígonu",
    "Sides" : "Cares",
    "Rectangle" : "Rectángulu",
    "Corner Radius" : "Radiu del contornu",
    "Width in pixels" : "Llargura en píxeles",
    "Height in pixels" : "Altor en píxeles",
    "Toggle ratio lock" : "Des/bloquiar la proporción",
    "Reset to original image size" : "Restaurar el tamañu orixinal",
    "Rotate" : "Voltiar",
    "Text" : "Testu",
    "Text spacing" : "Espaciáu del testu",
    "Text alignment" : "Alliniación del testu",
    "Font family" : "Familia de la fonte",
    "Size" : "Tamañu",
    "Letter spacing" : "Espaciáu de les lletres",
    "Line height" : "Altor de les llinies",
    "Warmth" : "Calidez",
    "+ Add watermark" : "+ Amestar una marca d'agua",
    "Choose watermark type" : "Escoyer el tipu de marca d'agua",
    "Upload watermark" : "Xubir una marca d'agua",
    "Add as text" : "Amestar como testu",
    "Padding" : "Rellenu",
    "Shadow" : "Solombra",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacidá",
    "Position" : "Posición",
    "Stroke" : "Trazu",
    "Save image as" : "Guardar la imaxe como",
    "Extension" : "Estensión",
    "Name is required." : "El nome ye obligatoriu",
    "Quality" : "Calidá",
    "Saved image size (width x height)" : "Tamañu de la imaxe guardada (llargura x altor)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Decátate que l'área de recorte seleicionada ye menor que la redimensión aplicada lo que ye posible que cause una perda de calidá",
    "Actual size (100%)" : "Tamañu actual (100%)",
    "Fit size" : "Axustar el tamañu",
    "\"{fileName}\"" : "«{fileName}»"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/viewer/l10n/ast.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Un xestor de ficheros cenciellu con presentación de diapositives pa elementos multimedia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Comparti les últimes semeyes y vídeos de les vacaciones como nos filmes, amuesa un migayín de la to última novela dende Nextcloud, escueyi'l meyor GIF de la to coleición gracies a la previsualización direuta de los ficheros favoritos y fai munches más coses.",
    "Your browser does not support audio." : "El restolador nun ye compatible col audiu.",
    "Error loading {name}" : "Hebo un error al cargar «{name}»",
    "Image saved" : "Guardóse la imaxe",
    "Error saving image" : "Hebo un error al guardar la imaxe",
    "Unsaved changes" : "Cambeos ensin guardar",
    "Drop changes" : "Escartar los cambeos",
    "Play the live photo" : "Reproducir la semeya en direuto",
    "LIVE" : "EN DIREUTO",
    "Your browser does not support videos." : "El restolador nun ye compatible colos vídeos.",
    "Edit" : "Editar",
    "Exit full screen" : "Colar de la pantalla completa",
    "Full screen" : "Pantalla completa",
    "Open sidebar" : "Abrir la barra llateral",
    "Download" : "Baxar",
    "Delete" : "Desaniciar",
    "This file no longer exists" : "Esti ficheru yá nun esiste",
    "There is no plugin available to display this file type" : "Nun hai nengún plugin disponible p'amosar esti tipu de ficheru",
    "View" : "Ver",
    "Name" : "Nome",
    "Save" : "Guardar",
    "Save as" : "Guardar como",
    "Back" : "Atrás",
    "Loading …" : "Cargando…",
    "Reset" : "Reafitar",
    "All changes will be lost." : "Van perdese tolos cambeos.",
    "Are you sure you want to continue?" : "¿De xuru que quies siguir?",
    "Cancel" : "Encaboxar",
    "Apply" : "Aplicar",
    "Warning" : "Alvertencia",
    "Confirm" : "Confirmar",
    "Discard changes" : "Escartar los cambeos",
    "Undo" : "Desfacer",
    "Redo" : "Refacer",
    "Show original image" : "Amosar la imaxe orixinal",
    "Zoom in" : "Averar",
    "Zoom out" : "Alloñar",
    "Toggle zoom menu" : "Alternar el menú del zoom",
    "Adjust" : "Axustar",
    "Fine-tune" : "Axuste finu",
    "Filters" : "Filtros",
    "Watermark" : "Marca d'agua",
    "Draw" : "Dibuxar",
    "Resize" : "Redimensionar",
    "Invalid image." : "La imaxe ye inválida.",
    "Error while uploading the image." : "Hebo un error mentanto se xubía la imaxe.",
    "are not images" : "nun son imáxenes",
    "is not an image" : "nun ye una imaxe",
    "to be uploaded" : "a xubir",
    "Crop" : "Recortar",
    "Original" : "Orixinal",
    "Custom" : "Personalizar",
    "Square" : "Cuadráu",
    "Landscape" : "Horizontal",
    "Portrait" : "Vertical",
    "Ellipse" : "Elipse",
    "Classic TV" : "TV clásica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flecha",
    "Blur" : "Emborrinar",
    "Brightness" : "Brillu",
    "Contrast" : "Contraste",
    "Flip X" : "Voltiar la exa X",
    "Flip Y" : "Voltiar la exa Y",
    "HSV" : "HSV",
    "Hue" : "Tonu",
    "Saturation" : "Saturación",
    "Value" : "Valor",
    "Image" : "Imaxe",
    "Importing …" : "Importando…",
    "+ Add image" : "+ Amestar una imaxe",
    "Line" : "Llinia",
    "Pen" : "Pluma",
    "Polygon" : "Polígonu",
    "Sides" : "Cares",
    "Rectangle" : "Rectángulu",
    "Corner Radius" : "Radiu del contornu",
    "Width in pixels" : "Llargura en píxeles",
    "Height in pixels" : "Altor en píxeles",
    "Toggle ratio lock" : "Des/bloquiar la proporción",
    "Reset to original image size" : "Restaurar el tamañu orixinal",
    "Rotate" : "Voltiar",
    "Text" : "Testu",
    "Text spacing" : "Espaciáu del testu",
    "Text alignment" : "Alliniación del testu",
    "Font family" : "Familia de la fonte",
    "Size" : "Tamañu",
    "Letter spacing" : "Espaciáu de les lletres",
    "Line height" : "Altor de les llinies",
    "Warmth" : "Calidez",
    "+ Add watermark" : "+ Amestar una marca d'agua",
    "Choose watermark type" : "Escoyer el tipu de marca d'agua",
    "Upload watermark" : "Xubir una marca d'agua",
    "Add as text" : "Amestar como testu",
    "Padding" : "Rellenu",
    "Shadow" : "Solombra",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacidá",
    "Position" : "Posición",
    "Stroke" : "Trazu",
    "Save image as" : "Guardar la imaxe como",
    "Extension" : "Estensión",
    "Name is required." : "El nome ye obligatoriu",
    "Quality" : "Calidá",
    "Saved image size (width x height)" : "Tamañu de la imaxe guardada (llargura x altor)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Decátate que l'área de recorte seleicionada ye menor que la redimensión aplicada, lo que ye posible que cause una perda de calidá",
    "Actual size (100%)" : "Tamañu actual (100%)",
    "Fit size" : "Axustar el tamañu",
    "Menu" : "Menú",
    "Height" : "Altor",
    "Continue" : "Siguir"
},
"nplurals=2; plural=(n != 1);");
